<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Lists the sequences currently known to the wizard, and allows users
 * to set which ones can be accessed.
 *
 * @package   block
 * @subpackage low_sequence_list
 * @copyright 2012 Moodle Wizard development team
 * @authors    Anthony Franzi, Edward Walker
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../config.php');

require_once($CFG->dirroot . '/blocks/low_wizard/lib.php');


$id = optional_param('id', 0, PARAM_INT);
$delete = optional_param('delete', ',', PARAM_TEXT);

$PAGE->set_url('/blocks/low_sequence_list/sequence_list.php', array(
                'id' 	=> $id,
));

$sitecontext = get_context_instance(CONTEXT_SYSTEM);
$PAGE->set_context(context_system::instance()); //yeah!
$PAGE->set_pagetype('site-index');
$PAGE->set_pagelayout('standard');
$PAGE->set_title($SITE->fullname);
$PAGE->set_heading($SITE->fullname);

require_login();

// Process delete request.
// ',' can never be the name of a flowchart because the comma
// has a special meaning in the authorisations file.
if($delete != NULL && $delete != ',')
{	
	// Update the authorisations file.
	$sequences = block_low_wizard_get_sequence_list();
	unset($sequences[$delete]);
	block_low_wizard_save_sequence_list($sequences);
	
	unlink('../../blocks/low_wizard/learning_outcomes/'.$delete.'.json');
}

echo $OUTPUT->header();

echo $OUTPUT->heading_with_help(get_string('modulename', 'block_low_sequence_list'), 'modulename' , 'block_low_sequence_list', '', '');

require_once("$CFG->libdir/formslib.php");

class simplehtml_form extends moodleform {

    function definition() {
        global $CFG;

		require_once($CFG->dirroot . '/blocks/low_wizard/lib.php');
        $list = block_low_wizard_get_sequence_list();
        $mform =& $this->_form; 

		
		//$mform->addElement('hidden', 'reply', 'yes');
		$mform->addElement('header', 'sequencelist', 'Available Sequence Lists');  //This line starts the form and removes the extra tag errors generated by mforms.
		$mform->addElement('html', '<table border="0" cellpadding="20" cellspacing="0">
				<tr><th>Selected sequences are available for use in the Wizard</th><th>View Sequence</th><th>Delete Sequence</th></tr>');
				
        foreach ($list as $chart => $authorised) {
            
            // URL encode the chart name to remove spaces, so that it works as an ID attribute.
            $id = urlencode($chart);
			
                //Add Checkbox
				$mform->addElement('html', '<tr><td>');
				
		        if ($authorised != BLOCK_WIZARD_AUTH_BROKEN) {
		            
    				$mform->addElement('advcheckbox', $id , '' ,  $chart, array('group' => 1), array(0,1));
    				
					
					
    				if ($authorised == BLOCK_WIZARD_AUTH_YES) {
    				    $mform->setDefault($id, 1);
    				    
    				}
    				
		        } else {
		            
		            // Add a warning instead of the checkbox.
		            $mform->addElement("html", $chart . " (<strong>References Nonexistent Activity</strong>)");
		        }
				//Add View and Delete Buttons
				$mform->addElement('html', '<td><input type="button" id="view'.$chart.'" onclick="View(this.id)" value="View"></td>');
				$mform->addElement('html', '<td><input type="button" id="delete'.$chart.'" onclick="Delete(this.id)" value="Delete"></td>');
                
        }

		$mform->addElement('html', '</div></table>');
    	$mform->addElement('hidden', 'delete', ',', array('id' => 'delete'));
		
        $this->add_action_buttons($cancel = false);

    }                           // Close the function
}                               // Close the class


?>
<script type="text/javascript">

// Handler for when the user clicks the view button
function View(name)
{
	var name = name.substring(4);
	var answer = confirm("Would you like to view "+name+"?")
	if (answer){
		window.location = "../low_generator/generator.php?id=0&flowchart="+name;
	}
	else{
		alert("Thanks for sticking around!")
	}


return;
}

// Handler for when the user clicks the delete button
function Delete(name)
{
    var name = name.substring(6);
    var answer = confirm("Are you sure you want to delete " + name)
    
	if (answer){
		
		alert(name+" has been deleted");

		deleted_name = document.getElementById('delete');
		deleted_name.value = name;

		var the_form = document.getElementById('delete' + name).form;
		the_form.submit();

		//return true;
		//return false;
	}
return;
}

</script>

<?php 







$list = block_low_wizard_get_sequence_list();
		
		
$mform_simple = new simplehtml_form( null, array() );

$mform_simple->display();

$output_changed_list = array();

foreach ($list as $chart => $authorised) {
    
    /*
     * It isn't possible to authorise a broken file.
     * 
     * In the current
     * implementation of the generator, it's impossible to edit
     * a flowchart once it's been created -- you have to save the new
     * version under a new name.
     * 
     * This means we don't need a way to authorise a broken flowchart,
     * since the broken activity can't be removed.
     */
    if ($authorised === BLOCK_WIZARD_AUTH_BROKEN) {
        
        $output_changed_list[$chart] = BLOCK_WIZARD_AUTH_BROKEN;
        continue;
    }
    
    // URL encode chart names to remove spaces and other special characters.
    $id = urlencode($chart);

    if ($mform_simple->is_cancelled()) {
        // they've cancelled

    } else if ($mform_simple->get_data($id)) {

        $formdata = $mform_simple->get_data($id);
        
            if ($formdata->$id == 1){
                 
                $output_changed_list[$chart] = BLOCK_WIZARD_AUTH_YES;

            } else {
                $output_changed_list[$chart] = BLOCK_WIZARD_AUTH_NO;
            }

            block_low_wizard_save_sequence_list ($output_changed_list);
//        }
    }
    else {
        
        // TODO: need a branch for if the form is submitted and doesn't validate. (see Moodle docs)
    }
	
	
}

echo $OUTPUT->footer();
